@@ -51,7 +51,6 @@
 
 #include <config.h>
 
-#include <libgnomevfs/gnome-vfs-i18n.h>
 #include <libgnomevfs/gnome-vfs-context.h>
 #include <libgnomevfs/gnome-vfs-method.h>
 #include <libgnomevfs/gnome-vfs-module.h>
@@ -67,6 +66,8 @@
 #include <errno.h>
 #include <stdlib.h>
 
+#include <glib/gi18n-lib.h>
+
 #include "sftp.h"
 #include "pty-open.h"
 
@@ -163,9 +164,9 @@ static gboolean sftp_connection_process_errors (GIOChannel *channel,
 
 typedef struct
 {
-	guchar  *base;
-	guchar  *read_ptr;
-	guchar  *write_ptr;
+	char  *base;
+	char  *read_ptr;
+	char  *write_ptr;
 	gint     alloc;
 } Buffer;
 
@@ -701,7 +702,7 @@ iobuf_read_handle (int fd, gchar **handle, guint expected_id, guint32 *len)
 		g_critical ("Expected SSH2_FXP_HANDLE(%u) packet, got %u",
 			    SSH2_FXP_HANDLE, type);
 
-	*handle = buffer_read_block (&msg, len);
+	*handle = buffer_read_block (&msg, (gint32 *)len);
 
 	buffer_free (&msg);
 
@@ -1061,7 +1062,7 @@ sftp_connect (SftpConnection **connection, const GnomeVFSURI *uri)
 	guint           last_arg, i;
 	gboolean        full_auth;
 	gboolean        done_auth;
-	gboolean	save_password;
+	gboolean	save_password = FALSE;
 	Buffer          msg;
 	gchar           type;
 	char *password = NULL;
@@ -1751,7 +1752,7 @@ do_open (GnomeVFSMethod        *method,
 	guint id;
 	gint32 sftp_mode;
 	gchar *sftp_handle;
-	gint sftp_handle_len, sftp_res;
+	gint sftp_handle_len;
 	gchar *path;
 
 	DEBUG (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s: Enter", __FUNCTION__));
@@ -1787,9 +1788,9 @@ do_open (GnomeVFSMethod        *method,
 	buffer_send (&msg, conn->out_fd);
 	buffer_free (&msg);
 	
-	sftp_res = iobuf_read_handle (conn->in_fd, &sftp_handle, id, &sftp_handle_len);
+	res = iobuf_read_handle (conn->in_fd, &sftp_handle, id, (guint32 *)&sftp_handle_len);
 
-	if (sftp_res == SSH2_FX_OK) {
+	if (res == GNOME_VFS_OK) {
 		handle = g_new0 (SftpOpenHandle, 1);
 		handle->sftp_handle = sftp_handle;
 		handle->sftp_handle_len = sftp_handle_len;
@@ -1807,7 +1808,7 @@ do_open (GnomeVFSMethod        *method,
 		sftp_connection_unlock (conn);
 
 		DEBUG (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s: Exit", __FUNCTION__));
-		return sftp_status_to_vfs_result (sftp_res);
+		return res;
 	}
 }
 
@@ -1828,7 +1829,6 @@ do_create (GnomeVFSMethod        *method,
 	Buffer msg;
 	int id;
 	int ssh_mode;
-	guint sftp_res;
 
 	gchar *sftp_handle;
 	guint sftp_handle_len;
@@ -1874,10 +1874,10 @@ do_create (GnomeVFSMethod        *method,
 	buffer_send (&msg, conn->out_fd);
 	buffer_free (&msg);
 
-	sftp_res = iobuf_read_handle (conn->in_fd, &sftp_handle, id, &sftp_handle_len);
+	res = iobuf_read_handle (conn->in_fd, &sftp_handle, id, &sftp_handle_len);
 
 
-	if (sftp_res == SSH2_FX_OK) {
+	if (res == GNOME_VFS_OK) {
 		handle = g_new0 (SftpOpenHandle, 1);
 		handle->sftp_handle = sftp_handle;
 		handle->sftp_handle_len = sftp_handle_len;
@@ -1895,7 +1895,7 @@ do_create (GnomeVFSMethod        *method,
 		sftp_connection_unlock (conn);
 		
 		DEBUG (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s: Exit", __FUNCTION__));
-		return sftp_status_to_vfs_result (sftp_res);
+		return res;
 	}
 }
 
@@ -2281,7 +2281,7 @@ do_seek (GnomeVFSMethod       *method,
 static GnomeVFSResult
 do_tell (GnomeVFSMethod       *method,
 	 GnomeVFSMethodHandle *method_handle,
-	 GnomeVFSFileOffset   *offset_return)
+	 GnomeVFSFileSize   *offset_return)
 {
 	SftpOpenHandle *handle;
 
@@ -2413,7 +2413,6 @@ do_open_directory (GnomeVFSMethod          *method,
 	gchar *sftp_handle;
 	Buffer msg;
 	guint id, sftp_handle_len;
-	guint sftp_res;
 	gchar *path;
 
 	DEBUG (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s: Enter", __FUNCTION__));
@@ -2445,11 +2444,11 @@ do_open_directory (GnomeVFSMethod          *method,
 
 	buffer_free (&msg);
 
-	sftp_res = iobuf_read_handle (conn->in_fd, &sftp_handle, id, &sftp_handle_len);
+	res = iobuf_read_handle (conn->in_fd, &sftp_handle, id, &sftp_handle_len);
 
-	DEBUG (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s: Result is %d", __FUNCTION__, sftp_res));
+	DEBUG (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s: Result is %d", __FUNCTION__, res));
 
-	if (sftp_res == SSH2_FX_OK) {
+	if (res == GNOME_VFS_OK) {
 		handle = g_new0 (SftpOpenHandle, 1);
 		handle->sftp_handle = sftp_handle;
 		handle->sftp_handle_len = sftp_handle_len;
@@ -2468,15 +2467,15 @@ do_open_directory (GnomeVFSMethod          *method,
 		return GNOME_VFS_OK;
 	} else {
 		/* For some reason, some servers report EOF when the directory doesn't exist. *shrug* */
-		if (sftp_res == SSH2_FX_EOF)
-			sftp_res = SSH2_FX_NO_SUCH_FILE;
+		if (res == GNOME_VFS_ERROR_EOF)
+			res = GNOME_VFS_ERROR_NOT_FOUND;
 
 		sftp_connection_unref (conn);
 		sftp_connection_unlock (conn);
 
 		*method_handle = NULL;
 		DEBUG (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s: Exit", __FUNCTION__));
-		return sftp_status_to_vfs_result (sftp_res);
+		return res;
 	}
 }
 
